@@ -80,7 +80,7 @@ class Pandora:
 		try:
 			parsed = xmlrpclib.loads( resp )[0][0]
 		except xmlrpclib.Fault, fault:
-			parsed = xmlrpclib.loads( resp )
+			parsed = resp
 			print "Error:", fault.faultString
 			print "Code:", fault.faultCode
 
@@ -110,7 +110,7 @@ class Pandora:
 		try:
 			parsed = xmlrpclib.loads( resp )[0][0]
 		except xmlrpclib.Fault, fault:
-			parsed = xmlrpclib.loads( resp )
+			parsed = resp
 			print "Error:", fault.faultString
 			print "Code:", fault.faultCode
 
@@ -135,7 +135,7 @@ class Pandora:
 		try:
 			parsed = xmlrpclib.loads( resp )[0][0]
 		except xmlrpclib.Fault, fault:
-			parsed = xmlrpclib.loads( resp )
+			parsed = resp
 			print "Error:", fault.faultString
 			print "Code:", fault.faultCode
 
@@ -160,7 +160,7 @@ class Pandora:
 		try:
 			parsed = xmlrpclib.loads( resp )[0][0]
 		except xmlrpclib.Fault, fault:
-			parsed = xmlrpclib.loads( resp )
+			parsed = resp
 			print "Error:", fault.faultString
 			print "Code:", fault.faultCode
 
@@ -185,7 +185,7 @@ class Pandora:
 		try:
 			parsed = xmlrpclib.loads( resp )[0][0]
 		except xmlrpclib.Fault, fault:
-			parsed = xmlrpclib.loads( resp )
+			parsed = resp
 			print "Error:", fault.faultString
 			print "Code:", fault.faultCode
 
@@ -210,7 +210,7 @@ class Pandora:
 		try:
 			parsed = xmlrpclib.loads( resp )[0][0]
 		except xmlrpclib.Fault, fault:
-			parsed = xmlrpclib.loads( resp )
+			parsed = resp
 			print "Error:", fault.faultString
 			print "Code:", fault.faultCode
 
@@ -236,7 +236,7 @@ class Pandora:
 		try:
 			parsed = xmlrpclib.loads( resp )[0][0]
 		except xmlrpclib.Fault, fault:
-			parsed = xmlrpclib.loads( resp )
+			parsed = resp
 			print "Error:", fault.faultString
 			print "Code:", fault.faultCode
 
