@@ -1,7 +1,9 @@
-#!/usr/bin/python2.5
+#!/usr/bin/python
 import os
 import sys,time,re
-import osso
+try:
+	import osso
+except: print "Not N900"
 import webbrowser
 from PyQt4 import QtGui,QtCore
 from PyQt4.QtCore import *
@@ -13,7 +15,6 @@ from radioplayer import RadioPlayer
 import gobject, dbus
 from dbus.mainloop.glib import DBusGMainLoop
 
-
 __title__ = "Pandora"
 
 class snooze(QtCore.QThread):
@@ -92,6 +93,9 @@ class Panda(QtGui.QMainWindow):
 		self.c.load()
 		self.player = RadioPlayer()
 		self.player.start()
+		self.pui = Ui_pyRadio_portrait()
+		self.pui.setupUi(self)
+		self.pui = None
 		self.ui = Ui_pyRadio()
 		self.ui.setupUi(self)
 		if not self.c.lastplayed == "":
@@ -285,6 +289,7 @@ class Panda(QtGui.QMainWindow):
 	def doLove( self ):
 		self.player.loveHateRating = True
 		self.player.loveHateSong = 1
+		self.player.curSong[1]["rating"] = 1
 		self.ui.btnLove.setStyleSheet("background-color: "+ self.c.color +";\n"
 		"border: rgb(0, 0, 0);\nbackground-image: url(:/img/img/Thumbs-up-right-trans.png);")
 
@@ -388,6 +393,9 @@ class Panda(QtGui.QMainWindow):
 			self.ui.listStations.addItem(sName)
 			if self.player.playStation>0 and s["stationId"] == self.player.playStation:
 				self.ui.listStations.setCurrentIndex(self.ui.listStations.count()-1)	
+	
+			if self.player.curStation>0 and s["stationId"] == self.player.curStation:
+				self.ui.listStations.setCurrentIndex(self.ui.listStations.count()-1)	
 
 	def setUserPass( self ):
 		self.c.user = ""
@@ -398,22 +406,19 @@ class Panda(QtGui.QMainWindow):
 		if not self.player.playing:
 			raise PandaException()
 		while self.player.playlist == []:
-			self.player.getPlaylist = 1
 			time.sleep( 0.5 )
 		next = self.player.playlist.pop( 0 )
 		self.player.curSong = next
 		self.player.startPlay = 1
 		self.setUi ( next )
-		if len( self.player.playlist ) == 0:
+		if self.player.playlist == []:
 			#Out of songs, grab some more while playing
 			self.player.getPlaylist = 1
 	
 	def setUi ( self, next=None ):
 		art = next[1]["art"]
-		self.ui.albumArt.setHtml("<img style='width: 100%; height: 95%' src='"+art+"'>")
+		self.ui.albumArt.setHtml("<table width='100%' height='100%'><tr><td vertical-align='middle' style='text-align: center'><img style='width: 80%; height: 80%' src='"+art+"'></td></tr></table>")
 		self.ui.lblAlbum.setText("\"" + next[1]["title"] + "\"" + " by " + next[1]["artist"] + "\n" + "on: " + next[1]["album"])
-		#self.setWindowTitle(QtGui.QApplication.translate("pyRadio", "\"" + next[1]["title"] + "\"" + " by " + next[1]["artist"] + " - pyRadio", None, QtGui.QApplication.UnicodeUTF8))
-		#self.ui.lblAlbum.setText("on: " + next[1]["album"])
 		if next[1]["rating"] > 0:
 			self.ui.btnLove.setStyleSheet("background-color: "+ self.c.color + ";\n"
 			"border: rgb(0, 0, 0);\nbackground-image: url(:/img/img/Thumbs-up-right-trans.png);")
@@ -424,8 +429,8 @@ class Panda(QtGui.QMainWindow):
 
 	def skipSong( self ):
 		self.player.skip = True
+		self.skip = 0
 		self.player.stopPlayBack()
-		self.player.onPlayBackStopped()
 
 	def stop( self ):
 		self.player.playing = False
