@@ -116,7 +116,10 @@ class RadioPlayer(QtCore.QThread):
 		self.play( item[0], item[1] )
 
 	def play( self, url, item ):
+		self.player.set_state(gst.STATE_NULL)
+		time.sleep ( 0.5 )
 		self.player.set_property('uri', url)
+		time.sleep ( 0.5 )
 		self.player.set_state(gst.STATE_PLAYING)
 
 	def stopPlayBack ( self,state=None ):
@@ -124,6 +127,8 @@ class RadioPlayer(QtCore.QThread):
 			self.player.set_state(gst.STATE_PAUSED)
 		else:
 			self.player.set_state(gst.STATE_NULL)
+			if self.skip:
+				self.onPlayBackStopped()
 	
 	def startPlayBack ( self ):
 		self.player.set_state(gst.STATE_PLAYING)
@@ -131,16 +136,11 @@ class RadioPlayer(QtCore.QThread):
 	def onPlayBackStopped( self ):
 		if self.playing:
 			if self.skip:
-				self.skip = 0
-			time.sleep( 0.5 )
-			self.emit(QtCore.SIGNAL("PlayNext"))
+				self.skip = False
+				self.emit(QtCore.SIGNAL("PlayNext"))
 
 	def onPlayBackEnded( self, bus, msg ):
 		if self.playing:
-			if self.skip:
-				self.skip = 0
-			self.player.set_state(gst.STATE_NULL)
-			time.sleep( 0.5 )
 			self.emit(QtCore.SIGNAL("PlayNext"))
 
 	def LoveHate( self ):
@@ -176,7 +176,7 @@ class RadioPlayer(QtCore.QThread):
 			"genre"		:	"".join(s["genre"]), \
 			"album"		:	s["albumTitle"], \
 			"rating"	:	s["rating"], \
-			"art"		: s["artistArtUrl"], \
+			"art"		: s["artRadio"], \
 			"matchingSeed"	: s["matchingSeed"], \
 			"userSeed"	: s["userSeed"], \
 			"focusTraitId"	: s["focusTraitId"], \
